/****************************************************************************
**  MDHashTool - Message Digest (MD5, SHA-1, etc.) tool
**  Copyright (c) 2005  Charles Melhorn
**
**  This file is part of MDHashTool.
**
**  MDHashTool is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  MDHashTool is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
**  Or see the GNU web site at: http://www.gnu.org
**
****************************************************************************/ 

var gTargetFile = null;

var nsIMDHash = Components.interfaces.nsIMDHash;
var gMDHashTool = Components.classes["@mozilla.org/mdhashtool;1"]
                  .createInstance(nsIMDHash);


function initMDHTInfo()
{
  var hashtype_db = document.getElementById("mdht-hashtype-dropbox"); 
  hashtype_db.value = gMDHTUserPreferenceInfo.getPrefValue("default_hash_alg");  

}


function getHash()
{
  var hash_type, checksum;
  var hash_type_db = document.getElementById("mdht-hashtype-dropbox");

  switch(hash_type_db.value)
  {
    case "MD5":  hash_type = nsIMDHash.HASH_MD5;
                 break;

    case "SHA1": hash_type = nsIMDHash.HASH_SHA1;
                 break;

    default:     hash_type = nsIMDHash.HASH_MD5;
                 break;
  }

  var input_type = document.getElementById("inputtype-rgroup").selectedItem.value;

  if (input_type == "file")
   {
    if (gTargetFile)
     {
       checksum = gMDHashTool.getHashForFile(hash_type, gTargetFile);
     }
   }
  else
   {
     var input_text = document.getElementById("text-input-tbox").value;
     checksum = gMDHashTool.getHashForString(hash_type, input_text);
   }

  document.getElementById("mdht-mdigest-desc").value = checksum;
}


function browseMDInputFiles()
{
  var nsIFilePicker = Components.interfaces.nsIFilePicker;
  var fp = Components.classes["@mozilla.org/filepicker;1"]
           .createInstance(nsIFilePicker);

  fp.init(window, "Select a File", nsIFilePicker.modeOpen);
  fp.appendFilters(nsIFilePicker.filterAll);

  var res = fp.show();

  if (res == nsIFilePicker.returnOK)
   {
     gTargetFile = fp.file;
     document.getElementById("file-input-tbox").value = fp.fileURL.spec;
     document.getElementById("mdht-mdigest-desc").value = "";
   }


}



function changeMDInputType(inputTypeStr)
{
  var msg_input_deck = document.getElementById("msg-input-deck");
  msg_input_deck.selectedIndex = ((inputTypeStr == "file") ? 0 : 1);

  document.getElementById("mdht-mdigest-desc").value = "";
}



function copyStringToClipboard(aString)
{
  var clipboardHelper = Components.classes["@mozilla.org/widget/clipboardhelper;1"]
                           .getService(Components.interfaces.nsIClipboardHelper);

  clipboardHelper.copyString(aString);  
}


function compareMessageDigests()
{
  var digestInfo = {};
  var input_type = document.getElementById("inputtype-rgroup").selectedItem.value;

  if (input_type == "file")
   {
     digestInfo.input = document.getElementById("file-input-tbox").value;
     digestInfo.intype = "file"
   }
  else
   {
     digestInfo.input = "\"" + document.getElementById("text-input-tbox").value + "\"";
     digestInfo.intype = "text"
   }

  digestInfo.alg = document.getElementById("mdht-hashtype-dropbox").value;
  digestInfo.md = document.getElementById("mdht-mdigest-desc").value;

  window.openDialog('chrome://mdhashtool/content/dialogCompare.xul',
                    'mdhtCompare','chrome,centerscreen,modal', digestInfo);

}


///////////////////////////////////////////////////////////////////////////////
// Drag and Drop

var gMDHTDNDObserver =
{
  onDragOver: function (aEvent, aFlavour, aDragSession)
  {
    aDragSession.canDrop = true;
  },
  
  onDrop: function(aEvent, aXferData, aDragSession)
  {
    var hash_type, checksum;
    var url = transferUtils.retrieveURLFromData(aXferData.data,
                                                aXferData.flavour.contentType);

    var hash_type_db = document.getElementById("mdht-hashtype-dropbox");

    switch(hash_type_db.value)
    {
      case "MD5":  hash_type = nsIMDHash.HASH_MD5;
                   break;

      case "SHA1": hash_type = nsIMDHash.HASH_SHA1;
                   break;

      default:     hash_type = nsIMDHash.HASH_MD5;
                   break;
    }

    if (aXferData.flavour.contentType == "application/x-moz-file")
     {
       var inputItem = document.getElementById("itype-file-rbtn");
       document.getElementById("inputtype-rgroup").selectedItem = inputItem;
       document.getElementById("file-input-tbox").value = url;
       document.getElementById('msg-input-deck').selectedIndex = 0;

       gTargetFile = aXferData.data;
       checksum = gMDHashTool.getHashForFile(hash_type, gTargetFile);
     }
    else if (aXferData.flavour.contentType == "text/unicode")
     {
       var inputItem = document.getElementById("itype-text-rbtn");
       document.getElementById("inputtype-rgroup").selectedItem = inputItem;
       document.getElementById("text-input-tbox").value = url;
       document.getElementById('msg-input-deck').selectedIndex = 1;

       var input_text = document.getElementById("text-input-tbox").value;
       checksum = gMDHashTool.getHashForString(hash_type, input_text);
     }

    document.getElementById("mdht-mdigest-desc").value = checksum;
  },

  _flavourSet: null,  
  getSupportedFlavours: function ()
  {
    if (!this._flavourSet) {
      this._flavourSet = new FlavourSet();
      this._flavourSet.appendFlavour("application/x-moz-file", "nsIFile");
      this._flavourSet.appendFlavour("text/unicode");
    }
    return this._flavourSet;
  }
}


